colour.plotting.phenomenon Module — Colour 0.3.0 documentation

# colour.plotting.phenomenon Module

## Optical Phenomenon Plotting

Defines the optical phenomenons plotting objects:

- `rayleigh_scattering_spd_plot()`
- `the_blue_sky_plot()`

`colour.plotting.phenomenon.` `single_rayleigh_scattering_spd_plot`(CO2_concentration=300, temperature=288.15, pressure=101325, latitude=0, altitude=0, cmfs='CIE 1931 2 Degree Standard Observer', **kwargs)

  Plots a single rayleigh scattering spectral power distribution.

  Parameters: | CO2_concentration (numeric, optional) – \(CO_2\) concentration in parts per million (ppm). temperature (numeric, optional) – Air temperature \(T[K]\) in kelvin degrees. pressure (numeric) – Surface pressure \(P\) of the measurement site. latitude (numeric, optional) – Latitude of the site in degrees. altitude (numeric, optional) – Altitude of the site in meters. cmfs (unicode, optional) – Standard observer colour matching functions. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> single_rayleigh_scattering_spd_plot()
      True

`colour.plotting.phenomenon.` `the_blue_sky_plot`(cmfs='CIE 1931 2 Degree Standard Observer', **kwargs)

  Plots the blue sky.

  Parameters: | cmfs (unicode, optional) – Standard observer colour matching functions. **kwargs (**) – Keywords arguments.
  Returns: | Definition success.
  Return type: | bool

  Examples

      >>> the_blue_sky_plot()
      True